@@ -28,84 +28,89 @@ Composer::Composer(bool forPublisher)
     this->setAcceptRichText(true);
     this->setTabChangesFocus(true);
 
+
+
+    startConversationLabel = new QLabel(tr("Click here or press Control+N to post a note..."));
+
+    toolsMenu = new QMenu(tr("Formatting"));
+    toolsMenu->addAction(QIcon::fromTheme(""),
+                         tr("Normal"),
+                         this,
+                         SLOT(makeNormal()));
+    toolsMenu->addAction(QIcon::fromTheme("format-text-bold"),
+                         tr("Bold"),
+                         this,
+                         SLOT(makeBold()),
+                         QKeySequence::Bold);
+    toolsMenu->addAction(QIcon::fromTheme("format-text-italic"),
+                         tr("Italic"),
+                         this,
+                         SLOT(makeItalic()),
+                         QKeySequence::Italic);
+    toolsMenu->addAction(QIcon::fromTheme("format-text-underline"),
+                         tr("Underline"),
+                         this,
+                         SLOT(makeUnderline()),
+                         QKeySequence::Underline);
+
+    toolsMenu->addSeparator();
+
+    toolsMenu->addAction(QIcon::fromTheme("format-justify-fill"),
+                         tr("Preformatted block"),
+                         this,
+                         SLOT(makePreformatted()));
+
+    toolsMenu->addSeparator();
+
+    toolsMenu->addAction(QIcon::fromTheme("insert-link"),
+                         tr("Make a link"),
+                         this,
+                         SLOT(makeLink()),
+                         QKeySequence("Ctrl+L"));
+    toolsMenu->addAction(QIcon::fromTheme("insert-image"),
+                         tr("Insert an image from a web site"),
+                         this,
+                         SLOT(insertImage()));
+
+    toolsMenu->addSeparator();
+
+    toolsMenu->addAction(QIcon::fromTheme("dialog-cancel"),
+                         tr("Cancel Post"),
+                         this,
+                         SLOT(cancelPost()));
+
+    toolsButton = new QPushButton(QIcon::fromTheme("format-list-ordered"), tr("&F", "F for formatting, translate accordingly"));
+    toolsButton->setMenu(toolsMenu);
+    toolsButton->setToolTip(tr("Text Formatting Options"));
+    toolsButton->setHidden(true); // Hidden on startup (Publisher in miniMode)
+
+
+    this->customContextMenu = this->createStandardContextMenu();
+    this->customContextMenu->addMenu(toolsMenu);
+
     mainLayout = new QGridLayout();
 
-    if (this->forPublisher)
+
+    if (this->forPublisher)  // Publisher mode
     {
         this->setToolTip(tr("Type a message here to post it"));
 
-
-        startConversationLabel = new QLabel(tr("Click here or press Control+N to post a note..."));
-
-
-        toolsMenu = new QMenu("tools-menu");
-        toolsMenu->addAction(QIcon::fromTheme(""),
-                             tr("Normal"),
-                             this,
-                             SLOT(makeNormal()));
-        toolsMenu->addAction(QIcon::fromTheme("format-text-bold"),
-                             tr("Bold"),
-                             this,
-                             SLOT(makeBold()));
-        toolsMenu->addAction(QIcon::fromTheme("format-text-italic"),
-                             tr("Italic"),
-                             this,
-                             SLOT(makeItalic()));
-        toolsMenu->addAction(QIcon::fromTheme(""),
-                             tr("Bold + Italic"),
-                             this,
-                             SLOT(makeBoldAndItalic()));
-        toolsMenu->addAction(QIcon::fromTheme("format-text-underline"),
-                             tr("Underline"),
-                             this,
-                             SLOT(makeUnderline()));
-
-        toolsMenu->addSeparator();
-
-        toolsMenu->addAction(QIcon::fromTheme("format-justify-fill"),
-                             tr("Preformatted block"),
-                             this,
-                             SLOT(makePreformatted()));
-
-        toolsMenu->addSeparator();
-
-        toolsMenu->addAction(QIcon::fromTheme("insert-link"),
-                             tr("Make a link"),
-                             this,
-                             SLOT(makeLink()));
-        toolsMenu->addAction(QIcon::fromTheme("insert-image"),
-                             tr("Insert an image from a web site"),
-                             this,
-                             SLOT(insertImage()));
-
-        toolsMenu->addSeparator();
-
-        toolsMenu->addAction(QIcon::fromTheme("dialog-cancel"),
-                             tr("Cancel Post"),
-                             this,
-                             SLOT(cancelPost()));
-
-        toolsButton = new QPushButton(QIcon::fromTheme("format-list-ordered"), tr("&F", "F for formatting, translate accordingly"));
-        toolsButton->setMenu(toolsMenu);
-        toolsButton->setToolTip(tr("Text Formatting Options"));
-        toolsButton->setHidden(true); // Hidden on startup (Publisher in miniMode)
-
-
         mainLayout->addWidget(startConversationLabel, 0, 0, 1, 1, Qt::AlignLeft | Qt::AlignVCenter);
-        mainLayout->addWidget(toolsButton,            0, 1, 1, 1, Qt::AlignRight | Qt::AlignTop);
     }
-    else // then, for commenter
+    else                     // or Commenter mode
     {
         this->setToolTip(tr("Type a comment here.\n"
                             "You can press Control+Enter to send the comment\n"
                             "with the keyboard, or ESC to cancel."));
     }
 
+    mainLayout->addWidget(toolsButton,            0, 1, 1, 1, Qt::AlignRight | Qt::AlignBottom);
     this->setLayout(mainLayout);
 
     qDebug() << "Composer box created";
 }
 
+
 Composer::~Composer()
 {
     qDebug() << "Composer box destroyed";
@@ -132,13 +137,13 @@ void Composer::erase()
  */
 void Composer::focusInEvent(QFocusEvent *event)
 {
-    emit focusReceived(); // inform Publisher() or Commenter() that we have focused
+    emit focusReceived(); // inform Publisher() or Commenter() that we have focus
 
     if (this->forPublisher)
     {
-        startConversationLabel->hide(); // hide placeholder message
-        toolsButton->show();
+        startConversationLabel->hide(); // hide placeholder message        
     }
+    toolsButton->show();
 
     QTextEdit::focusInEvent(event); // process standard event: allows context menu
 
@@ -151,8 +156,7 @@ void Composer::focusInEvent(QFocusEvent *event)
 void Composer::keyPressEvent(QKeyEvent *event)
 {
     //qDebug() << "Composer::keyPressEvent()";
-    //qDebug() << event->modifiers();
-    //qDebug() << event->key();
+
 
     // Control+Enter = Send message (post)
     if ((event->key() == Qt::Key_Enter || event->key() == Qt::Key_Return)
@@ -166,7 +170,7 @@ void Composer::keyPressEvent(QKeyEvent *event)
         qDebug() << "Escape was pressed";
         if (this->toPlainText().isEmpty())
         {
-            qDebug() << "There was no text, cancelling post";
+            qDebug() << "There was no text, canceling post";
             this->cancelPost();
         }
     }
@@ -177,8 +181,20 @@ void Composer::keyPressEvent(QKeyEvent *event)
 }
 
 
+/*
+ * For custom context menu
+ *
+ */
+void Composer::contextMenuEvent(QContextMenuEvent *event)
+{
+    customContextMenu->exec(event->globalPos());
+}
 
+
+
+/*************************************************************************/
 /****************************** SLOTS ************************************/
+/*************************************************************************/
 
 
 
@@ -194,38 +210,36 @@ void Composer::makeNormal()
 
 
 /*
- * Make selected text bold, by adding <b> and </b>
+ * Make selected text bold
  *
  */
 void Composer::makeBold()
 {
     //qDebug() << this->textCursor().selectionStart() << " -> "  << this->textCursor().selectionEnd();
-
-    QString selectedText = this->textCursor().selectedText();
-
-    if (!selectedText.isEmpty())
+    QTextCharFormat charFormat;
+    if (this->currentCharFormat().fontWeight() == QFont::Bold)
     {
-        this->textCursor().removeSelectedText();
-        this->insertHtml("<b>" + selectedText + "</b>");
+        charFormat.setFontWeight(QFont::Normal);
     }
+    else
+    {
+        charFormat.setFontWeight(QFont::Bold);
+    }
+    this->mergeCurrentCharFormat(charFormat);
 
     this->setFocus(); // give focus back to text editor
 }
 
 
 /*
- * Make selected text italic, by adding <i>
+ * Make selected text italic
  *
  */
 void Composer::makeItalic()
 {
-    QString selectedText = this->textCursor().selectedText();
-
-    if (!selectedText.isEmpty())
-    {
-        this->textCursor().removeSelectedText();
-        this->insertHtml("<i>" + selectedText + "</i>");
-    }
+    QTextCharFormat charFormat;
+    charFormat.setFontItalic(!this->currentCharFormat().fontItalic());
+    this->mergeCurrentCharFormat(charFormat);
 
     this->setFocus();
 }
@@ -233,36 +247,14 @@ void Composer::makeItalic()
 
 
 /*
- * Make selected text bold AND italic, by adding <b><i>
- *
- */
-void Composer::makeBoldAndItalic()
-{
-    QString selectedText = this->textCursor().selectedText();
-
-    if (!selectedText.isEmpty())
-    {
-        this->textCursor().removeSelectedText();
-        this->insertHtml("<b><i>" + selectedText + "</i></b>");
-    }
-
-    this->setFocus(); // give focus back to text editor
-}
-
-
-/*
- * Underline selected text italic, by adding <u> </u>
+ * Underline selected text
  *
  */
 void Composer::makeUnderline()
 {
-    QString selectedText = this->textCursor().selectedText();
-
-    if (!selectedText.isEmpty())
-    {
-        this->textCursor().removeSelectedText();
-        this->insertHtml("<u>" + selectedText + "</u>");
-    }
+    QTextCharFormat charFormat;
+    charFormat.setFontUnderline(!this->currentCharFormat().fontUnderline());
+    this->mergeCurrentCharFormat(charFormat);
 
     this->setFocus();
 }
@@ -325,7 +317,7 @@ void Composer::makeLink()
         link = link.trimmed(); // Remove possible spaces before or after
 
         this->textCursor().removeSelectedText();
-        this->insertHtml("<a href=\"" + link + "\">" + selectedText + "</a>");
+        this->insertHtml("<a href=\"" + link + "\">" + selectedText + "</a> ");
     }
     else
     {
@@ -385,7 +377,8 @@ void Composer::cancelPost()
         cancelConfirmed = QMessageBox::question(this,
                                                 tr("Cancel message?"),
                                                 tr("Are you sure you want to cancel this message?"),
-                                                tr("&Yes, cancel it"), tr("&No"));
+                                                tr("&Yes, cancel it"), tr("&No"),
+                                                "", 1, 1);
 
     }
 
@@ -397,7 +390,7 @@ void Composer::cancelPost()
         // emit signal to make Publisher go back to minimum mode
         emit editingCancelled();
 
-        qDebug() << "Post cancelled";
+        qDebug() << "Post canceled";
     }
 
 
