@@ -51,7 +51,6 @@ public slots:
     void makeNormal();
     void makeBold();
     void makeItalic();
-    void makeBoldAndItalic();
     void makeUnderline();
     void makePreformatted();
     void makeLink();
@@ -63,6 +62,7 @@ public slots:
 protected:
     virtual void focusInEvent(QFocusEvent *event);
     virtual void keyPressEvent(QKeyEvent *event);
+    virtual void contextMenuEvent(QContextMenuEvent *event);
 
 private:
     QGridLayout *mainLayout;
@@ -71,6 +71,8 @@ private:
     QPushButton *toolsButton;
     QMenu *toolsMenu;
 
+    QMenu *customContextMenu;
+
     bool forPublisher;
 };
 
