@@ -21,38 +21,31 @@
 #include "configdialog.h"
 
 ConfigDialog::ConfigDialog(int updateInterval, int postsPerPage, int tabsPosition,
-                           bool tabsMovable, int publisherType, int showNotifications)
+                           bool tabsMovable, int publisherType, bool publicPosts,
+                           int showNotifications, QWidget *parent)
 {
-    this->setWindowTitle(tr("Configure Dianara"));
+    this->setWindowTitle("Dianara - " + tr("Program Configuration"));
     this->setWindowIcon(QIcon::fromTheme("configure"));
-    this->setMinimumSize(450, 300);
+    this->setWindowFlags(Qt::Window);
+    this->setWindowModality(Qt::ApplicationModal);
+    this->setMinimumSize(480, 320);
 
-    mainLayout = new QGridLayout();
 
-    updateIntervalLabel = new QLabel(tr("Timeline update interval"));
-    updateIntervalLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-    mainLayout->addWidget(updateIntervalLabel, 0, 0);
+    // Upper part
+
+    optionsLayout = new QFormLayout();
 
     updateIntervalSpinbox = new QSpinBox();
     updateIntervalSpinbox->setRange(2, 60); // 2-60 min
     updateIntervalSpinbox->setSuffix(" "+ tr("minutes"));
     updateIntervalSpinbox->setValue(updateInterval);
-    mainLayout->addWidget(updateIntervalSpinbox, 0, 1);
-
-    postsPerPageLabel = new QLabel(tr("Posts per page"));
-    postsPerPageLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-    mainLayout->addWidget(postsPerPageLabel, 1, 0);
+    optionsLayout->addRow(tr("Timeline &update interval"), updateIntervalSpinbox);
 
     postsPerPageSpinbox = new QSpinBox();
     postsPerPageSpinbox->setRange(10, 100); // 10-100 ppp
     postsPerPageSpinbox->setSuffix(" "+ tr("posts"));
     postsPerPageSpinbox->setValue(postsPerPage);
-    mainLayout->addWidget(postsPerPageSpinbox, 1, 1);
-
-
-    tabsPositionLabel = new QLabel(tr("Tabs position"));
-    tabsPositionLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-    mainLayout->addWidget(tabsPositionLabel, 2, 0);
+    optionsLayout->addRow(tr("&Posts per page"), postsPerPageSpinbox);
 
 
     tabsPositionCombobox = new QComboBox();
@@ -65,24 +58,12 @@ ConfigDialog::ConfigDialog(int updateInterval, int postsPerPage, int tabsPositio
     tabsPositionCombobox->addItem(QIcon::fromTheme("arrow-right"),
                                   tr("Right side"));
     tabsPositionCombobox->setCurrentIndex(tabsPosition);
-    mainLayout->addWidget(tabsPositionCombobox, 2, 1);
-
-
-
-    tabsMovableLabel = new QLabel(tr("Movable tabs"));
-    tabsMovableLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-    mainLayout->addWidget(tabsMovableLabel, 3, 0);
+    optionsLayout->addRow(tr("&Tabs position"), tabsPositionCombobox);
 
 
     tabsMovableCheckbox = new QCheckBox();
     tabsMovableCheckbox->setChecked(tabsMovable);
-    mainLayout->addWidget(tabsMovableCheckbox, 3, 1);
-
-
-
-    publisherTypeLabel = new QLabel(tr("Composer type"));
-    publisherTypeLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-    mainLayout->addWidget(publisherTypeLabel, 4, 0);
+    optionsLayout->addRow(tr("&Movable tabs"), tabsMovableCheckbox);
 
 
     publisherTypeCombobox = new QComboBox();
@@ -91,13 +72,13 @@ ConfigDialog::ConfigDialog(int updateInterval, int postsPerPage, int tabsPositio
     publisherTypeCombobox->addItem(tr("Buttons on right side"));
     publisherTypeCombobox->setCurrentIndex(publisherType);
     publisherTypeCombobox->setToolTip(tr("Restart program to apply this change"));
-    mainLayout->addWidget(publisherTypeCombobox, 4, 1);
+    optionsLayout->addRow(tr("C&omposer type"), publisherTypeCombobox);
 
 
+    publicPostsCheckbox = new QCheckBox();
+    publicPostsCheckbox->setChecked(publicPosts);
+    optionsLayout->addRow(tr("Public posts as &default"), publicPostsCheckbox);
 
-    showNotificationsLabel = new QLabel(tr("Show notifications"));
-    showNotificationsLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-    mainLayout->addWidget(showNotificationsLabel, 5, 0);
 
     showNotificationsCombobox = new QComboBox();
     showNotificationsCombobox->addItem(QIcon::fromTheme("preferences-desktop-notification"),
@@ -107,24 +88,33 @@ ConfigDialog::ConfigDialog(int updateInterval, int postsPerPage, int tabsPositio
     showNotificationsCombobox->addItem(QIcon::fromTheme("user-busy"), // dialog-cancel
                                        tr("Don't show notifications"));
     showNotificationsCombobox->setCurrentIndex(showNotifications);
-    mainLayout->addWidget(showNotificationsCombobox, 5, 1);
+    optionsLayout->addRow(tr("Show &notifications"), showNotificationsCombobox);
 
 
+    // Bottom part
 
     saveConfigButton = new QPushButton(QIcon::fromTheme("document-save"),
                                  tr("&Save configuration"));
     connect(saveConfigButton, SIGNAL(clicked()),
             this, SLOT(saveConfiguration()));
-    mainLayout->addWidget(saveConfigButton, 10, 0,
-                          1, 1, Qt::AlignRight);
     cancelButton = new QPushButton(QIcon::fromTheme("dialog-cancel"),
                                    tr("&Cancel"));
     connect(cancelButton, SIGNAL(clicked()),
             this, SLOT(hide()));
-    mainLayout->addWidget(cancelButton, 10, 1,
-                          1, 1, Qt::AlignRight);
+
+    this->buttonsLayout = new QHBoxLayout();
+    buttonsLayout->setAlignment(Qt::AlignRight);
+    buttonsLayout->addWidget(saveConfigButton);
+    buttonsLayout->addWidget(cancelButton);
 
 
+    // Set up main layout
+
+    mainLayout = new QVBoxLayout();
+    mainLayout->addLayout(optionsLayout, 2);
+    mainLayout->addSpacing(32);
+    mainLayout->addStretch(1);
+    mainLayout->addLayout(buttonsLayout);
     this->setLayout(mainLayout);
 
 
@@ -137,7 +127,9 @@ ConfigDialog::~ConfigDialog()
 }
 
 
-//////// SLOTS
+
+///////////////////////////////// SLOTS //////////////////////////////////////
+
 
 
 void ConfigDialog::saveConfiguration()
@@ -147,6 +139,7 @@ void ConfigDialog::saveConfiguration()
                               tabsPositionCombobox->currentIndex(),
                               tabsMovableCheckbox->isChecked(),
                               publisherTypeCombobox->currentIndex(),
+                              publicPostsCheckbox->isChecked(),
                               showNotificationsCombobox->currentIndex());
     qDebug() << "ConfigDialog: saved config";
 
