@@ -84,8 +84,24 @@ ContactList::ContactList(PumpController *pumpController,
     followersScrollArea->setWidgetResizable(true);
 
 
+    // Widget for the list of 'lists'
+    this->listsLabel = new QLabel();
+    listsLabel->setAlignment(Qt::AlignHCenter | Qt::AlignTop);
+
+    listsScrollArea = new QScrollArea();
+    listsScrollArea->setWidget(listsLabel);
+    listsScrollArea->setWidgetResizable(true);
+
+
+    reloadFollowersButton = new QPushButton(QIcon::fromTheme("view-refresh"),
+                                            tr("Refresh"));
+    reloadFollowersButton->setToolTip(tr("Reload list of followers"));
+    connect(reloadFollowersButton, SIGNAL(clicked()),
+            this, SLOT(refreshFollowers()));
+
+
     this->tabWidget = new QTabWidget();
-    tabWidget->setDocumentMode(true); // To have less margins, with so many tabs inside tabs..
+    tabWidget->setDocumentMode(true); // To have less margins, with so many tabs inside tabs...
 
     tabWidget->addTab(followingScrollArea,
                       QIcon::fromTheme("meeting-participant"),
@@ -93,9 +109,16 @@ ContactList::ContactList(PumpController *pumpController,
     tabWidget->addTab(followersScrollArea,
                       QIcon::fromTheme("meeting-observer"),
                       "followers");
+    tabWidget->addTab(listsScrollArea,
+                      QIcon::fromTheme("preferences-contact-list"),
+                      "lists");
+
+    tabWidget->setCornerWidget(this->reloadFollowersButton);
+
 
     this->followingCount = 0;
     this->followersCount = 0;
+    this->listsCount = 0;
     this->setTabLabels();
 
 
@@ -144,6 +167,9 @@ void ContactList::setTabLabels()
 
     this->tabWidget->setTabText(1, tr("Follo&wers")
                                    + QString(" (%1)").arg(this->followersCount));
+
+    this->tabWidget->setTabText(2, tr("&Lists")
+                                   + QString(" (%1)").arg(this->listsCount));
 }
 
 
@@ -177,13 +203,13 @@ void ContactList::setContactListContents(QString listType, QVariantList contactL
 
     foreach (QVariant contact, contactList)
     {
-        contactData.insert("id", contact.toMap().value("id").toString().remove(0,5)); // remove "acct:"
-        contactData.insert("name", contact.toMap().value("displayName").toString());
-        contactData.insert("avatar", contact.toMap().value("image").toMap().value("url").toString());
-        contactData.insert("hometown", contact.toMap().value("location").toMap().value("displayName").toString());
-        contactData.insert("bio", contact.toMap().value("summary").toString());
+        contactData.insert("id", contact.toMap()["id"].toString().remove(0,5)); // remove "acct:"
+        contactData.insert("name", contact.toMap()["displayName"].toString());
+        contactData.insert("avatar", contact.toMap()["image"].toMap().value("url").toString());
+        contactData.insert("hometown", contact.toMap()["location"].toMap().value("displayName").toString());
+        contactData.insert("bio", contact.toMap()["summary"].toString());
 
-        contactData.insert("following", contact.toMap().value("pump_io").toMap().value("followed").toString());
+        contactData.insert("following", contact.toMap()["pump_io"].toMap().value("followed").toString());
 
         if (listType == "following")
         {
@@ -208,6 +234,59 @@ void ContactList::setContactListContents(QString listType, QVariantList contactL
 
 
 
+/*
+ * Fill the list of lists
+ *
+ */
+void ContactList::setListsListContents(QVariantList listsList)
+{
+    qDebug() << "Setting lists list contents";
+
+    QString listName;
+    int listMembersCount;
+
+    QString listsString = "<br>"
+                          "<table align=\"center\">"
+                          "<tr>"
+                          "<td>" + tr("Name") + "</td>"
+                          "<td>&nbsp;&nbsp;&nbsp;</td>"
+                          "<td align=\"right\">" + tr("Members") + "<br><br></td>"
+                          "</tr>";
+    foreach (QVariant list, listsList)
+    {
+        listName = list.toMap()["displayName"].toString();
+        listMembersCount = list.toMap()["members"].toMap()["totalItems"].toInt();
+
+        listsString.append("<tr>");
+        listsString.append(QString("<td><b>%1</b></td>").arg(listName));
+        listsString.append("<td></td>");
+        listsString.append(QString("<td align=\"right\">%1<br></td>").arg(listMembersCount));
+        listsString.append("</tr>");
+    }
+    listsString.append("</table>");
+
+
+    this->listsLabel->setText(listsString);
+
+
+    this->listsCount = listsList.count();
+    // Update tab labels with number of following or followers, which were updated before
+    this->setTabLabels();
+}
+
+
+/*
+ * Ask for the updated list of followers
+ *
+ */
+void ContactList::refreshFollowers()
+{
+    qDebug() << "Refreshing list of followers...";
+    this->pController->getContactList("followers");
+}
+
+
+
 
 /*
  * Add the address entered by the user to the /following list.
