@@ -57,6 +57,9 @@ signals:
 public slots:
     void setContactListContents(QString listType,
                                 QVariantList contactList);
+    void setListsListContents(QVariantList listsList);
+
+    void refreshFollowers();
 
     void followContact();
 
@@ -81,6 +84,14 @@ private:
     int followersCount;
 
 
+    QLabel *listsLabel;
+    QScrollArea *listsScrollArea;
+    int listsCount;
+
+
+
+    QPushButton *reloadFollowersButton;
+
     PumpController *pController;
 };
 
