@@ -33,7 +33,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     prepareDataDirectory();
 
     reallyQuitProgram = false;
-
+    trayIconAvailable = false;
 
 
     // Network control
@@ -54,11 +54,11 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
                                      Qt::KeepAspectRatio,
                                      Qt::SmoothTransformation));
     leftLayout->addWidget(avatarIconLabel);
-    leftLayout->addSpacing(8);
+    leftLayout->addSpacing(4);
 
-    fullNameLabel = new QLabel("-Your-Name-");
+    fullNameLabel = new QLabel("[----------]");
     leftLayout->addWidget(fullNameLabel);
-    leftLayout->addSpacing(16);
+    leftLayout->addSpacing(8);
 
 
     leftPanel = new QToolBox(); // For now, only one "section"...
@@ -78,7 +78,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     rightSideWidget = new QWidget();
     rightLayout = new QVBoxLayout();
 
-    this->publisherType = settings.value("publisherType", 0).toInt(); // TMP/FIXME?
+    this->publisherType = settings.value("Configuration/publisherType", 0).toInt(); // TMP/FIXME?
     publisher = new Publisher(pumpController, publisherType);
 
 
@@ -90,9 +90,11 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     mainTimelineScrollArea->setWidgetResizable(true); // Seems to work in opposite way
     connect(mainTimeline, SIGNAL(scrollToTop()),
             this, SLOT(scrollMainTimelineToTop()));
+    connect(mainTimeline, SIGNAL(timelineRendered(int,int)),
+            this, SLOT(setTimelineTabTitle(int,int)));
 
-    connect(mainTimeline, SIGNAL(timelineRendered(int)),
-            this, SLOT(notifyTimelineUpdate(int)));
+    connect(mainTimeline, SIGNAL(timelineRendered(int,int)),
+            this, SLOT(notifyTimelineUpdate(int,int)));
 
 
     directTimeline = new TimeLine(TimeLine::TimelineTypeDirect,
@@ -103,6 +105,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     directTimelineScrollArea->setWidgetResizable(true);
     connect(directTimeline, SIGNAL(scrollToTop()),
             this, SLOT(scrollDirectTimelineToTop()));
+    connect(directTimeline, SIGNAL(timelineRendered(int,int)),
+            this, SLOT(setTimelineTabTitle(int,int)));
 
 
     activityTimeline = new TimeLine(TimeLine::TimelineTypeActivity,
@@ -113,6 +117,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     activityTimelineScrollArea->setWidgetResizable(true);
     connect(activityTimeline, SIGNAL(scrollToTop()),
             this, SLOT(scrollActivityTimelineToTop()));
+    connect(activityTimeline, SIGNAL(timelineRendered(int,int)),
+            this, SLOT(setTimelineTabTitle(int,int)));
 
 
     favoritesTimeline = new TimeLine(TimeLine::TimelineTypeFavorites,
@@ -123,6 +129,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     favoritesTimelineScrollArea->setWidgetResizable(true);
     connect(favoritesTimeline, SIGNAL(scrollToTop()),
             this, SLOT(scrollFavoritesTimelineToTop()));
+    connect(favoritesTimeline, SIGNAL(timelineRendered(int,int)),
+            this, SLOT(setTimelineTabTitle(int,int)));
 
 
 
@@ -133,24 +141,30 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     tabWidget = new QTabWidget();
     tabWidget->addTab(mainTimelineScrollArea,
                       QIcon::fromTheme("view-list-details"),
-                      tr("&Timeline"));
+                      "MAIN TIMELINE TAB");
     tabWidget->setTabToolTip(0, tr("The main timeline"));
+    this->setTimelineTabTitle(TimeLine::TimelineTypeMain, 0);
     tabWidget->addTab(directTimelineScrollArea,
                       QIcon::fromTheme("mail-message"),
-                      tr("&Messages"));
+                      "MESSAGES TAB");
     tabWidget->setTabToolTip(1, tr("Messages sent explicitly to you"));
+    this->setTimelineTabTitle(TimeLine::TimelineTypeDirect, 0);
     tabWidget->addTab(activityTimelineScrollArea,
                       QIcon::fromTheme("user-home"),
-                      tr("&Activity"));
+                      "ACTIVITY TAB");
     tabWidget->setTabToolTip(2, tr("Your own posts"));
+    this->setTimelineTabTitle(TimeLine::TimelineTypeActivity, 0);
     tabWidget->addTab(favoritesTimelineScrollArea,
                       QIcon::fromTheme("folder-favorites"),
-                      tr("Favorites"));
+                      "FAVORITES TAB");
     tabWidget->setTabToolTip(3, tr("Your favorited posts"));
+    this->setTimelineTabTitle(TimeLine::TimelineTypeFavorites, 0);
     tabWidget->addTab(contactList,
                       QIcon::fromTheme("system-users"),
                       tr("&Contacts"));
     tabWidget->setTabToolTip(4, tr("The people you follow, and the ones who follow you"));
+    connect(tabWidget, SIGNAL(currentChanged(int)),
+            this, SLOT(setTitleAndTrayInfo(int)));
 
 
 
@@ -182,11 +196,15 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     updateTimer = new QTimer(this);
     updateTimer->setInterval(this->updateInterval * 1000 * 60); // min > msec
-    connect(updateTimer, SIGNAL(timeout()), this, SLOT(updateTimelines()));
+    connect(updateTimer, SIGNAL(timeout()),
+            this, SLOT(updateMainDirectMinorTimelines()));
     updateTimer->start();
 
 
-    accountDialog = new AccountDialog(pumpController);
+    profileEditor = new ProfileEditor(pumpController, this);
+
+
+    accountDialog = new AccountDialog(pumpController, this);
     connect(accountDialog, SIGNAL(userIDChanged(QString)),
             this, SLOT(updateUserID(QString)));
 
@@ -195,9 +213,11 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
                                     this->tabsPosition,
                                     this->tabsMovable,
                                     this->publisherType,
-                                    this->showNotifications);
-    connect(configDialog, SIGNAL(configurationChanged(int,int,int,bool,int,int)),
-            this, SLOT(updateSettings(int,int,int,bool,int,int)));
+                                    this->publicPosts,
+                                    this->showNotifications,
+                                    this);
+    connect(configDialog, SIGNAL(configurationChanged(int,int,int,bool,int,bool,int)),
+            this, SLOT(updateSettings(int,int,int,bool,int,bool,int)));
 
 
 
@@ -205,8 +225,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     //////////////////////////////// Connections for PumpController //////////
     ///
 
-    connect(pumpController, SIGNAL(profileReceived(QString,QString)),
-            this, SLOT(updateProfileData(QString,QString)));
+    connect(pumpController, SIGNAL(profileReceived(QString,QString,QString,QString)),
+            this, SLOT(updateProfileData(QString,QString,QString,QString)));
 
     connect(pumpController, SIGNAL(avatarPictureReceived(QByteArray,QUrl)),
             this, SLOT(storeAvatar(QByteArray,QUrl)));
@@ -227,9 +247,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     // After sucessful posting, request updated timeline, with your post included
     connect(pumpController, SIGNAL(postPublished()),
-            this, SLOT(updateTimelines()));
-    // FIXME: update other timelines, if appropiate
-    // (activity timeline, yes, direct timeline, no)
+            this, SLOT(updateMainActivityMinorTimelines()));
 
 
     // After successful liking, update likes count
@@ -239,8 +257,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
             directTimeline, SLOT(setLikesInPost(QVariantList,QString)));
     connect(pumpController, SIGNAL(likesReceived(QVariantList,QString)),
             activityTimeline, SLOT(setLikesInPost(QVariantList,QString)));
+    // We don't update likes count in favorites timeline,
+    // since it still doesn't know about this post
+
+    // Instead, reload favorites timeline
     connect(pumpController, SIGNAL(likesReceived(QVariantList,QString)),
-            favoritesTimeline, SLOT(setLikesInPost(QVariantList,QString)));
+            favoritesTimeline, SLOT(goToFirstPage()));
+
+
     // After commenting successfully, refresh list of comments in that post
     connect(pumpController, SIGNAL(commentsReceived(QVariantList,QString)),
             mainTimeline, SLOT(setCommentsInPost(QVariantList,QString)));
@@ -266,6 +290,12 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     connect(pumpController, SIGNAL(contactListReceived(QString,QVariantList)),
             contactList, SLOT(setContactListContents(QString,QVariantList)));
 
+    // After receiving the list of lists, update it
+    connect(pumpController, SIGNAL(listsListReceived(QVariantList)),
+            contactList, SLOT(setListsListContents(QVariantList)));
+
+
+
     // Show notifications for events sent from pumpController
     connect(pumpController, SIGNAL(showNotification(QString)),
             fdNotifier, SLOT(showMessage(QString)));
@@ -295,11 +325,18 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     this->statusBar()->showMessage(tr("Initializing..."));
 
 
+    settings.beginGroup("MainWindow");
+
     // Now set the "view side panel" checkable menu to its saved state
     // That will also trigger the action to hide/show it
     viewSidePanel->setChecked(settings.value("viewSidePanel", true).toBool());
 
 
+    // Set the "view status bar" checkable menu to its saved state, which
+    // will also trigger the action to hide/show it
+    viewStatusBar->setChecked(settings.value("viewStatusBar", true).toBool());
+
+    settings.endGroup();
 
     qDebug() << "MainWindow created";
 }
@@ -444,7 +481,7 @@ void MainWindow::createMenus()
                                          this);
     sessionUpdateAllTimelines->setShortcut(QKeySequence("Ctrl+F5"));
     connect(sessionUpdateAllTimelines, SIGNAL(triggered()),
-            this, SLOT(updateTimelines()));
+            this, SLOT(updateAllTimelines()));
     sessionMenu->addAction(sessionUpdateAllTimelines);
 
     sessionMenu->addSeparator();
@@ -475,7 +512,7 @@ void MainWindow::createMenus()
     viewMenu = new QMenu(tr("&View"));
 
     viewSidePanel = new QAction(QIcon::fromTheme("view-sidetree"),
-                                tr("View Side &Panel"), this);
+                                tr("Side &Panel"), this);
     connect(viewSidePanel, SIGNAL(toggled(bool)),
             this, SLOT(toggleSidePanel(bool)));
     viewSidePanel->setCheckable(true);
@@ -484,18 +521,36 @@ void MainWindow::createMenus()
 
     viewMenu->addAction(viewSidePanel);
 
+    viewStatusBar = new QAction(QIcon::fromTheme("configure-toolbars"),
+                                tr("Status &Bar"), this);
+    connect(viewStatusBar, SIGNAL(toggled(bool)),
+            this, SLOT(toggleStatusBar(bool)));
+    viewStatusBar->setCheckable(true);
+    viewStatusBar->setChecked(true);
+
+    viewMenu->addAction(viewStatusBar);
+
     this->menuBar()->addMenu(viewMenu);
 
 
 
     settingsMenu = new QMenu(tr("S&ettings"));
 
-    settingsAccount = new QAction(QIcon::fromTheme("user-properties"),
+    settingsEditProfile = new QAction(QIcon::fromTheme("user-properties"),
+                                      tr("Edit &Profile"), this);
+    connect(settingsEditProfile, SIGNAL(triggered()),
+            profileEditor, SLOT(show()));
+    settingsMenu->addAction(settingsEditProfile);
+
+
+    settingsAccount = new QAction(QIcon::fromTheme("dialog-password"),
                                   tr("&Account Details"), this);
     connect(settingsAccount, SIGNAL(triggered()),
             accountDialog, SLOT(show()));
     settingsMenu->addAction(settingsAccount);
 
+    settingsMenu->addSeparator();
+
     settingsConfigure = new QAction(QIcon::fromTheme("configure"),
                                     tr("&Configure Dianara"), this);
     connect(settingsConfigure, SIGNAL(triggered()),
@@ -552,29 +607,34 @@ void MainWindow::createMenus()
 void MainWindow::createTrayIcon()
 {
     trayIcon = new QSystemTrayIcon(QIcon::fromTheme("dianara",
-                                                    QIcon(":/icon/64x64/dianara.png")), this);
-    if (!userID.isEmpty())
+                                                    QIcon(":/icon/32x32/dianara.png")), this);
+
+    if (trayIcon->isSystemTrayAvailable())
     {
-        trayIcon->setToolTip("Dianara - " + this->userID);
+        trayIconAvailable = true;
+
+        this->setTitleAndTrayInfo(this->tabWidget->currentIndex());
+
+
+        // Catch clicks on icon
+        connect(trayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
+                this, SLOT(trayControl(QSystemTrayIcon::ActivationReason)));
+
+
+        // Set contextual menu for the icon
+        trayIcon->setContextMenu(this->trayContextMenu);
+
+
+        trayIcon->show();
+
+        qDebug() << "Tray icon created";
     }
     else
     {
-        trayIcon->setToolTip("Dianara - [ " + tr("Your Pump.io account is not configured") + " ]");
+        trayIconAvailable = false;
+
+        qDebug() << "System tray not available";
     }
-
-
-    // Catch clicks on icon
-    connect(trayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
-            this, SLOT(trayControl(QSystemTrayIcon::ActivationReason)));
-
-
-    // Set contextual menu for the icon
-    trayIcon->setContextMenu(this->trayContextMenu);
-
-
-    trayIcon->show();
-
-    qDebug() << "Tray icon created";
 }
 
 
@@ -587,43 +647,60 @@ void MainWindow::loadSettings()
 {
     QSettings settings;
 
-    this->setWindowTitle("Dianara - " + settings.value("userID",
-                                                       tr("[ Configure your account ]")).toString());
+    firstRun = settings.value("firstRun", true).toBool();
+    if (firstRun)
+    {
+        qDebug() << "This is the first run";
+    }
+
+
+    userID = settings.value("userID", "").toString();
+    this->setTitleAndTrayInfo(tabWidget->currentIndex());
+
+
+
+    // Main window state
+    settings.beginGroup("MainWindow");
 
     this->resize(settings.value("windowSize", QSize(640, 450)).toSize());
+    if (!firstRun)
+    {
+        this->move(settings.value("windowPosition").toPoint());
+    }
     this->mainSplitter->restoreState(settings.value("mainSplitterState",
                                                     mainSplitter->saveState()).toByteArray());
     // Set childrenCollapsible to false AFTER loading state, to make sure state does not mess with it
     mainSplitter->setChildrenCollapsible(false);
 
+    settings.endGroup();
+
+
+    // General program configuration
+    settings.beginGroup("Configuration");
 
     this->updateInterval = settings.value("updateInterval", 5).toInt();
 
+    this->postsPerPage = settings.value("postsPerPage", 20).toInt();
+    this->pumpController->setPostsPerPage(this->postsPerPage);
+
+
     this->tabsPosition = settings.value("tabsPosition", QTabWidget::North).toInt();
     tabWidget->setTabPosition((QTabWidget::TabPosition)tabsPosition);
 
     this->tabsMovable = settings.value("tabsMovable", true).toBool();
     tabWidget->setMovable(tabsMovable);
 
+
     // publisherType 0 by default, buttons below
     this->publisherType = settings.value("publisherType", 0).toInt();
 
+    this->publicPosts = settings.value("publicPosts", false).toBool();
+    this->publisher->setDefaultPublicPosting(this->publicPosts);
+
+
     this->showNotifications = settings.value("showNotifications", 0).toInt();
 
-    firstRun = settings.value("firstRun", true).toBool();
-    if (firstRun)
-    {
-        qDebug() << "This is the first run";
-    }
-    else
-    {
-        this->move(settings.value("windowPosition").toPoint());
-        userID = settings.value("userID", "").toString();
-        userAuth = settings.value("userAuth", "").toByteArray();
-    }
-
-    this->postsPerPage = settings.value("postsPerPage", 20).toInt();
-    this->pumpController->setPostsPerPage(this->postsPerPage);
+    settings.endGroup();
 
 
     qDebug() << "Settings loaded";
@@ -639,28 +716,46 @@ void MainWindow::saveSettings()
 
     settings.setValue("firstRun", false);
 
+    // General main window status
+    settings.beginGroup("MainWindow");
+
     settings.setValue("windowSize", this->size());
     settings.setValue("windowPosition", this->pos());
     settings.setValue("mainSplitterState", this->mainSplitter->saveState());
 
     settings.setValue("viewSidePanel", this->viewSidePanel->isChecked());
+    settings.setValue("viewStatusBar", this->viewStatusBar->isChecked());
+
+    settings.endGroup();
+
+
+    // From config dialog
+    settings.beginGroup("Configuration");
 
     settings.setValue("updateInterval", this->updateInterval);
 
+    settings.setValue("postsPerPage", this->postsPerPage);
+
     settings.setValue("tabsPosition", this->tabsPosition);
     settings.setValue("tabsMovable", this->tabsMovable);
 
     settings.setValue("publisherType", this->publisherType);
+    settings.setValue("publicPosts", this->publicPosts);
 
     settings.setValue("showNotifications", this->showNotifications);
 
-    settings.setValue("postsPerPage", this->postsPerPage);
+    settings.endGroup();
+
 
     qDebug() << "Settings saved";
 }
 
 
-///////////// SLOTS
+
+//////////////////////////////////////////////////////////////////////////////
+/////////////////////////////////// SLOTS ////////////////////////////////////
+//////////////////////////////////////////////////////////////////////////////
+
 
 
 /*
@@ -671,8 +766,8 @@ void MainWindow::updateUserID(QString newUserID)
 {
     this->userID = newUserID;
 
-    this->setWindowTitle("Dianara - " + userID);
-    this->trayIcon->setToolTip("Dianara - " + userID);
+    // update window title and tray icon tooltip
+    this->setTitleAndTrayInfo(tabWidget->currentIndex());
 
     this->pumpController->setUserCredentials(userID);
 
@@ -695,7 +790,8 @@ void MainWindow::updateUserID(QString newUserID)
  */
 void MainWindow::updateSettings(int newUpdateInterval, int newPostsPerPage,
                                 int newTabsPosition, bool newTabsMovable,
-                                int newPublisherType, int newShowNotifications)
+                                int newPublisherType, bool newPublicPosts,
+                                int newShowNotifications)
 {
     this->updateInterval = newUpdateInterval;
     this->updateTimer->setInterval(updateInterval * 1000 * 60);
@@ -711,13 +807,18 @@ void MainWindow::updateSettings(int newUpdateInterval, int newPostsPerPage,
 
     this->publisherType = newPublisherType;
 
+    this->publicPosts = newPublicPosts;
+    this->publisher->setDefaultPublicPosting(this->publicPosts);
+
     this->showNotifications = newShowNotifications;
     fdNotifier->setNotificationType(showNotifications); // FIXME: Safe?
 
+
     qDebug() << "updateInterval updated:" << updateInterval << updateInterval*60000;
     qDebug() << "tabsPosition updated:" << tabsPosition << tabWidget->tabPosition();
     qDebug() << "tabsMovable updated:" << tabsMovable;
     qDebug() << "publisherType updated:" << publisherType;
+    qDebug() << "public posts updated:" << publicPosts;
     qDebug() << "Notifications updated:" << showNotifications;
 }
 
@@ -772,19 +873,19 @@ void MainWindow::trayControl(QSystemTrayIcon::ActivationReason reason)
  */
 void MainWindow::showTrayFallbackMessage(QString message)
 {
-    // if FreeDesktop.org notifications are not available,
-    // fall back to Qt's balloon ones
-    this->trayIcon->showMessage(tr("Dianara notification"),
+    this->trayIcon->showMessage(tr("Dianara Notification"),
                                 message,
                                 QSystemTrayIcon::Information,
                                 4000); // 4 secs
 }
 
 
-void MainWindow::updateProfileData(QString fullName, QString avatarURL)
+
+void MainWindow::updateProfileData(QString avatarURL, QString fullName,
+                                   QString hometown, QString bio)
 {
     this->fullNameLabel->setText(fullName);
-    qDebug() << "Updated profile data from server:" << fullName;
+    qDebug() << "Updated profile data from server:" << fullName << " @" << hometown;
     this->avatarURL = avatarURL;
     qDebug() << "Own avatar URL:" << avatarURL;
 
@@ -806,18 +907,54 @@ void MainWindow::updateProfileData(QString fullName, QString avatarURL)
         pumpController->getAvatar(avatarURL);
     }
 
+
+    // Fill/update this info in the profile editor too
+    this->profileEditor->setProfileData(avatarURL, fullName,
+                                        hometown, bio);
 }
 
 
+/*
+ * Update all timelines
+ *
+ */
+void MainWindow::updateAllTimelines()
+{
+    mainTimeline->goToFirstPage(); // received timeline will come in a SIGNAL()
+    directTimeline->goToFirstPage();
+    activityTimeline->goToFirstPage();
+    favoritesTimeline->goToFirstPage();
 
-void MainWindow::updateTimelines()
+    meanwhileFeed->updateFeed();
+
+    qDebug() << "Updated all timelines by menu";
+}
+
+/*
+ * Update some of the timelines:
+ *
+ * Main, Direct messages, and Minor feed
+ *
+ */
+void MainWindow::updateMainDirectMinorTimelines()
 {
     mainTimeline->goToFirstPage();
-    // received timeline data will come in a SIGNAL()
+    directTimeline->goToFirstPage();
 
-    meanwhileFeed->updateFeed(); // kinda TMP / FIXME
+    meanwhileFeed->updateFeed();
 
-    qDebug() << "Updated timelines by menu or after:" << this->updateInterval << "min";
+    qDebug() << "Updated some timelines by menu or after:" << this->updateInterval << "min";
+}
+
+
+void MainWindow::updateMainActivityMinorTimelines()
+{
+    mainTimeline->goToFirstPage();
+    activityTimeline->goToFirstPage();
+
+    meanwhileFeed->updateFeed();
+
+    qDebug() << "Updated some timelines by menu or after posting";
 }
 
 
@@ -848,7 +985,7 @@ void MainWindow::scrollFavoritesTimelineToTop()
 
 
 
-void MainWindow::notifyTimelineUpdate(int newPostCount)
+void MainWindow::notifyTimelineUpdate(int timelineType, int newPostCount)
 {
     if (newPostCount > 0)
     {
@@ -882,6 +1019,82 @@ void MainWindow::notifyTimelineUpdate(int newPostCount)
 }
 
 
+/*
+ * Update timelines titles with number of new posts
+ *
+ */
+void MainWindow::setTimelineTabTitle(int timelineType, int newPostCount)
+{
+    int updatedTab = 0;
+
+    QString messageCountString;
+    if (newPostCount > 0)
+    {
+        messageCountString = QString(" (%1)").arg(newPostCount);
+    }
+
+
+    switch (timelineType)
+    {
+    case TimeLine::TimelineTypeMain:
+        this->tabWidget->setTabText(0,
+                                    tr("&Timeline") + messageCountString);
+        updatedTab = 0;
+        break;
+
+    case TimeLine::TimelineTypeDirect:
+        this->tabWidget->setTabText(1,
+                                    tr("&Messages") + messageCountString);
+        updatedTab = 1;
+        break;
+
+    case TimeLine::TimelineTypeActivity:
+        this->tabWidget->setTabText(2,
+                                    tr("&Activity") + messageCountString);
+        updatedTab = 2;
+        break;
+
+    case TimeLine::TimelineTypeFavorites:
+        this->tabWidget->setTabText(3,
+                                    tr("Fav&orites") + messageCountString);
+        updatedTab = 3;
+        break;
+    }
+
+    // If the updated tab is the current one, set also window title, etc.
+    if (updatedTab == tabWidget->currentIndex())
+    {
+        this->setTitleAndTrayInfo(updatedTab);
+    }
+}
+
+
+/*
+ * Set mainWindow's title based on current tab, and user ID
+ *
+ * Use that same title as tray icon's tooltip
+ *
+ */
+void MainWindow::setTitleAndTrayInfo(int currentTab)
+{
+    QString currentTabTitle;
+    currentTabTitle = this->tabWidget->tabText(currentTab);
+    currentTabTitle.remove("&"); // Remove accelators
+
+    QString title = "Dianara - "
+                  + currentTabTitle
+                  + " - "
+                  + (userID.isEmpty() ?
+                     tr("[ Your Pump.io account is not configured ]") : userID);
+
+    this->setWindowTitle(title);
+    if (trayIconAvailable)
+    {
+        this->trayIcon->setToolTip(title);
+    }
+}
+
+
 
 
 /*
@@ -966,7 +1179,18 @@ void MainWindow::toggleSidePanel(bool shown)
     }
 
     qDebug() << "Showing side panel:" << shown;
-    this->leftSideWidget->setShown(shown);
+    this->leftSideWidget->setVisible(shown);
+}
+
+
+/*
+ * Hide or show the status bar
+ *
+ */
+void MainWindow::toggleStatusBar(bool shown)
+{
+    qDebug() << "Showing side panel:" << shown;
+    this->statusBar()->setVisible(shown);
 }
 
 
@@ -993,7 +1217,7 @@ void MainWindow::visitWebSite()
 void MainWindow::aboutDianara()
 {
     QMessageBox::about(this, tr("About Dianara"),
-                       "<b>Dianara v0.7</b><br>"
+                       "<b>Dianara v0.8</b><br>"
                        "Copyright 2012-2013  JanKusanagi<br><br>"
                        "<a href=\"http://jancoding.wordpress.com/dianara\">"
                        "http://jancoding.wordpress.com/dianara</a><br><br>"
