@@ -51,7 +51,7 @@
 
 #include <QDebug>
 
-#include "account.h"
+#include "accountdialog.h"
 #include "configdialog.h"
 #include "pumpcontroller.h"
 #include "notifications.h"
@@ -60,6 +60,7 @@
 #include "post.h"
 #include "contactlist.h"
 #include "minorfeed.h"
+#include "profileeditor.h"
 
 
 class MainWindow : public QMainWindow
@@ -85,20 +86,27 @@ public slots:
                         int newTabsPosition,
                         bool newTabsMovable,
                         int newPublisherType,
+                        bool newPublicPosts,
                         int newShowNotifications);
 
     void trayControl(QSystemTrayIcon::ActivationReason reason);
     void showTrayFallbackMessage(QString message);
 
-    void updateProfileData(QString fullName, QString avatarURL);
+    void updateProfileData(QString avatarURL, QString fullName,
+                           QString hometown, QString bio);
 
-    void updateTimelines();
+    void updateAllTimelines();
+    void updateMainDirectMinorTimelines();
+    void updateMainActivityMinorTimelines();
 
     void scrollMainTimelineToTop();
     void scrollDirectTimelineToTop();
     void scrollActivityTimelineToTop();
     void scrollFavoritesTimelineToTop();
-    void notifyTimelineUpdate(int newPostCount);
+    void notifyTimelineUpdate(int timelineType, int newPostCount);
+    void setTimelineTabTitle(int timelineType, int newPostCount);
+
+    void setTitleAndTrayInfo(int currentTab);
 
     void storeAvatar(QByteArray avatarData, QUrl avatarURL);
     void storeImage(QByteArray imageData, QUrl imageURL);
@@ -107,6 +115,8 @@ public slots:
 
 
     void toggleSidePanel(bool shown);
+    void toggleStatusBar(bool shown);
+
 
     void visitWebSite();
     void aboutDianara();
@@ -134,9 +144,14 @@ private:
     QAction *sessionUpdateAllTimelines;
     QAction *sessionPostNote;
     QAction *sessionQuit;
+
     QAction *viewSidePanel;
+    QAction *viewStatusBar;
+
+    QAction *settingsEditProfile;
     QAction *settingsAccount;
     QAction *settingsConfigure;
+
     QAction *helpVisitWebsite;
     QAction *helpAbout;
 
@@ -159,10 +174,12 @@ private:
 
 
     QSystemTrayIcon *trayIcon;
+    bool trayIconAvailable;
 
 
 
     AccountDialog *accountDialog;
+    ProfileEditor *profileEditor;
     ConfigDialog *configDialog;
     PumpController *pumpController;
     FDNotifications *fdNotifier;
@@ -196,12 +213,12 @@ private:
     int updateInterval;
     QTimer *updateTimer;
 
+    bool publicPosts;
+
     int showNotifications;
 
     // user account-related data
     QString userID;
-    QString userAuth;
-    QByteArray ownAvatarData;
 
 
 };
