@@ -21,7 +21,7 @@
 #ifndef MINORFEED_H
 #define MINORFEED_H
 
-#include <QFrame>
+#include <QTextBrowser>
 #include <QVBoxLayout>
 #include <QLabel>
 #include <QFont>
@@ -31,9 +31,10 @@
 
 #include "pumpcontroller.h"
 #include "timestamp.h"
+#include "mischelpers.h"
 
 
-class MinorFeed : public QFrame
+class MinorFeed : public QTextBrowser
 {
     Q_OBJECT
 
@@ -50,10 +51,6 @@ public slots:
 
 
 private:
-    QVBoxLayout *mainLayout;
-    QLabel *mainLabel;
-
-
     PumpController *pController;
 
 };
