@@ -67,9 +67,9 @@ Post::Post(PumpController *pumpController,
 
 
     QString authorTooltipInfo = postData.value("authorId");
+    authorTooltipInfo.append("<br>");
     if (!postData.value("authorHometown").isEmpty())
     {
-        authorTooltipInfo.append("<br>");
         authorTooltipInfo.append(tr("Hometown") + ": " + postData.value("authorHometown"));
         authorTooltipInfo.append("<br>");
     }
@@ -154,7 +154,8 @@ Post::Post(PumpController *pumpController,
     }
     else
     {
-        postCreatedAt->setToolTip(tr("Posted on %1, using %2","1=Date, 2=Program used")
+        postCreatedAt->setToolTip(tr("Posted on %1\n"
+                                     "using %2",        "1=Date of post, 2=Program used for posting")
                                   .arg(exactPostTime).arg(generator));
     }
     postCreatedAt->setTextFormat(Qt::PlainText);
@@ -655,10 +656,10 @@ void Post::resizeEvent(QResizeEvent *event)
     //postText->adjustSize();
     //postText->resize(postText->contentsRect().size());
     //postText->resize(postText->frameSize());
-
     //this->adjustSize();
 
-    postText->scroll(0, 0);
+    postText->moveCursor(QTextCursor::Start);
+
     event->accept();
 }
 
@@ -744,7 +745,8 @@ void Post::sendComment(QString comment)
 {
     qDebug() << "About to publish this comment:" << comment;
 
-    this->pController->addComment(comment, this->postID, this->postType);
+    this->pController->addComment(MiscHelpers::cleanHtml(comment),
+                                  this->postID, this->postType);
 }
 
 
@@ -762,7 +764,8 @@ void Post::sharePost()
 {
     int confirmation = QMessageBox::question(this, tr("Share post?"),
                                              tr("Do you want to share %1's post?").arg(this->postAuthorName->text()),
-                                             tr("&Yes, share it"), tr("&No"));
+                                             tr("&Yes, share it"), tr("&No"),
+                                             "", 1, 1);
 
     if (confirmation == 0)
     {
@@ -785,7 +788,7 @@ void Post::deletePost()
 {
     int confirmation = QMessageBox::question(this, tr("WARNING: Delete post?"),
                                              tr("Are you sure you want to delete this post?"),
-                                             tr("&Yes, delete it"), tr("&No"));
+                                             tr("&Yes, delete it"), tr("&No"), "", 1, 1);
 
     if (confirmation == 0)
     {
