@@ -22,7 +22,7 @@
 
 PumpController::PumpController(QObject *parent) :  QObject(parent)
 {
-    this->userAgentString = "Dianara/0.7";
+    this->userAgentString = "Dianara/0.8";
 
     this->postsPerPage = 20;
     this->updatesToTimelineBlocked = false;
@@ -42,7 +42,7 @@ PumpController::PumpController(QObject *parent) :  QObject(parent)
 
     if (isApplicationAuthorized)
     {
-        qDebug() << "Dianara is already authorized for user ID:" << this->userID;
+        qDebug() << "Dianara is already authorized for user ID:" << settings.value("userID");
 
         this->token = settings.value("token", "").toString().toLocal8Bit();
         this->tokenSecret = settings.value("tokenSecret", "").toString().toLocal8Bit();
@@ -187,6 +187,47 @@ void PumpController::getUserProfile(QString userID)
 }
 
 
+/*
+ * Update user's profile
+ *
+ */
+void PumpController::updateUserProfile(QString avatarURL, QString fullName,
+                                       QString hometown, QString bio)
+{
+    QString url = "https://" + this->serverURL + "/api/user/" + this->userName + "/profile";
+
+    QNetworkRequest updateProfileRequest = this->prepareRequest(url, QOAuth::PUT,
+                                                                UpdateProfileRequest);
+
+
+    QVariantMap jsonVariantImage;
+    jsonVariantImage.insert("url", avatarURL);
+
+    QVariantMap jsonVariantLocation;
+    jsonVariantLocation.insert("objectType", "place");
+    jsonVariantLocation.insert("displayName", hometown);
+
+    QVariantMap jsonVariant;
+    jsonVariant.insert("objectType", "person");
+    // TODO:
+    // jsonVariant.insert("image", jsonVariantImage);
+    jsonVariant.insert("displayName", fullName);
+    jsonVariant.insert("location", jsonVariantLocation);
+    jsonVariant.insert("summary", bio);
+
+
+
+    QJson::Serializer serializer;
+    bool ok;
+    QByteArray data = serializer.serialize(jsonVariant, &ok);
+
+
+
+    nam.put(updateProfileRequest, data);
+    qDebug() << "Updating user profile" << fullName << hometown;
+}
+
+
 
 
 void PumpController::getAvatar(QString avatarURL)
@@ -256,6 +297,27 @@ void PumpController::getContactList(QString listType)
 
 
 
+/*
+ * GET https://pumpserver.example/api/user/username/lists/person
+ *
+ */
+void PumpController::getListsList()
+{
+    qDebug() << "Getting list of lists";
+
+    QString url = "https://" + this->serverURL + "/api/user/" +this->userName + "/lists/person";
+
+    QNetworkRequest listsListRequest = this->prepareRequest(url, QOAuth::GET,
+                                                            ListsListRequest,
+                                                            QOAuth::ParamMap());
+
+    emit currentJobChanged(tr("Getting list of lists..."));
+
+    nam.get(listsListRequest);
+}
+
+
+
 
 /*
  * Get main timeline
@@ -469,13 +531,18 @@ QNetworkRequest PumpController::prepareRequest(QString url, QOAuth::HttpMethod m
                                                                  QOAuth::ParseForHeaderArguments);
 
     QNetworkRequest request;
-    // Don't append inline parameters if it's an image request, it messes up the filename
-    if (requestType != ImageRequest)
+
+    // Don't append inline parameters if they're empty, tha can mess up things
+    if (!paramMap.isEmpty())
     {
         url.append(qoauth->inlineParameters(paramMap, QOAuth::ParseForInlineQuery));
     }
     request.setUrl(QUrl(url));
-    request.setRawHeader("Authorization", authorizationHeader);
+    // Only add Authorization header if we're requesting something in our server
+    if (request.url().host() == this->serverURL)
+    {
+        request.setRawHeader("Authorization", authorizationHeader);
+    }
     request.setHeader(QNetworkRequest::ContentTypeHeader, contentTypeString);
     request.setRawHeader("User-Agent", userAgentString);
 
@@ -651,18 +718,22 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
         if (jsonParsedOK && jsonData.size() > 0)
         {
-            QString profId = jsonData["profile"].toMap()["id"].toString();
-            if (profId == "acct:" + this->userID)
+            QVariantMap profileMap = jsonData["profile"].toMap();
+
+            if (profileMap["id"].toString() == "acct:" + this->userID)
             {
                 qDebug() << "Received OWN profile";
 
-                QString profDisplayName = jsonData["profile"].toMap()["displayName"].toString();
-                QString profImageUrl = jsonData["profile"].toMap()["image"].toMap()["url"].toString();
+                QString profImageUrl = profileMap["image"].toMap()["url"].toString();
+                QString profDisplayName = profileMap["displayName"].toString();
+                QString profLocation = profileMap["location"].toMap()["displayName"].toString();
+                QString profSummary = profileMap["summary"].toString();
 
-                emit profileReceived(profDisplayName, profImageUrl);
+                emit profileReceived(profImageUrl, profDisplayName,
+                                     profLocation, profSummary);
 
                 // Store also the user's followers URL, for posting to Followers
-                this->userFollowersURL = jsonData["profile"].toMap().value("followers").toMap().value("url").toString();
+                this->userFollowersURL = profileMap["followers"].toMap()["url"].toString();
             }
         }
 
@@ -671,7 +742,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
 
 
 
-    ////////////////////////////////////////////////// If an timeline was requested
+    ////////////////////////////////////////////////// If a timeline was requested
     case MainTimelineRequest:
         // just jump to the next
     case DirectTimelineRequest:
@@ -715,7 +786,6 @@ void PumpController::requestFinished(QNetworkReply *reply)
                 qDebug() << "It was the favorites timeline";
                 emit favoritesTimelineReceived(jsonDataList, this->postsPerPage,
                                                previousLink, nextLink);
-                qDebug() << "#####################";
             }
         }
         else
@@ -816,7 +886,7 @@ void PumpController::requestFinished(QNetworkReply *reply)
             emit currentJobChanged(tr("Minor feed received."));
 
             jsonDataList = jsonData["items"].toList();
-            qDebug() << "Number of items in mitnor feed:" << jsonDataList.size();
+            qDebug() << "Number of items in minor feed:" << jsonDataList.size();
 
              emit minorFeedReceived(jsonDataList);
         }
@@ -891,6 +961,36 @@ void PumpController::requestFinished(QNetworkReply *reply)
         break;
 
 
+    case ListsListRequest:
+        qDebug() << "The list of lists was requested";
+
+        if (jsonParsedOK && jsonData.size() > 0)
+        {
+            qDebug() << "JSON parsed OK";
+
+            QVariant listsVariant = jsonData.value("items");
+            if (listsVariant.type() == QVariant::List)
+            {
+                qDebug() << "Parsed a List, listing lists...";
+
+                emit currentJobChanged(tr("List of 'lists' received."));
+                emit listsListReceived(listsVariant.toList());
+            }
+            else
+            {
+                qDebug() << "Expected a list of lists, received something else:";
+                qDebug() << jsonData;
+            }
+        }
+        else
+        {
+            qDebug() << "Error parsing received JSON data!";
+            qDebug() << "Raw data:" << packetData; // JSON directly
+        }
+
+        break;
+
+
 
     case AvatarRequest:
         qDebug() << "Received AVATAR data, from " << reply->url();
@@ -1157,6 +1257,10 @@ void PumpController::getInitialData()
         break;
 
     case 7:
+        this->getListsList();
+        break;
+
+    case 8:
         // Do nothing, so it takes longer for the final (default) step to arrive
         break;
 
@@ -1195,25 +1299,49 @@ void PumpController::postNote(QMap<QString, QString> audienceMap,
 
 
     QVariantList jsonVariantTo;
+    QVariantList jsonVariantCC;
+
     QVariantMap jsonVariantAudienceItem;
     while (!audienceMap.isEmpty())
     {
-        if (audienceMap.keys().contains("collection"))
+        jsonVariantAudienceItem.clear();
+
+        if (audienceMap.keys().contains("to|collection")) // To:
         {
-            QString collectionID = audienceMap.take("collection");
+            QString collectionID = audienceMap.take("to|collection");
             jsonVariantAudienceItem.insert("objectType", "collection");
             jsonVariantAudienceItem.insert("id", collectionID);
+
+            jsonVariantTo.append(jsonVariantAudienceItem);
         }
-        else if (audienceMap.keys().contains("person"))
+        else if (audienceMap.keys().contains("to|person"))
         {
-            QString personID = audienceMap.take("person");
+            QString personID = audienceMap.take("to|person");
             jsonVariantAudienceItem.insert("objectType", "person");
             jsonVariantAudienceItem.insert("id", personID);
+
+            jsonVariantTo.append(jsonVariantAudienceItem);
+        }
+        else if (audienceMap.keys().contains("cc|collection")) // CC:
+        {
+            QString collectionID = audienceMap.take("cc|collection");
+            jsonVariantAudienceItem.insert("objectType", "collection");
+            jsonVariantAudienceItem.insert("id", collectionID);
+
+            jsonVariantCC.append(jsonVariantAudienceItem);
+        }
+        else if (audienceMap.keys().contains("cc|person"))
+        {
+            QString personID = audienceMap.take("cc|person");
+            jsonVariantAudienceItem.insert("objectType", "person");
+            jsonVariantAudienceItem.insert("id", personID);
+
+            jsonVariantCC.append(jsonVariantAudienceItem);
         }
-        jsonVariantTo.append(jsonVariantAudienceItem);
     }
 
 
+
     QVariantMap jsonVariantObject;
     jsonVariantObject.insert("objectType", "note");
     jsonVariantObject.insert("content", postText);
@@ -1222,6 +1350,7 @@ void PumpController::postNote(QMap<QString, QString> audienceMap,
     jsonVariant.insert("verb", "post");
     jsonVariant.insert("object", jsonVariantObject);
     jsonVariant.insert("to", jsonVariantTo);
+    jsonVariant.insert("cc", jsonVariantCC);
 
 
 
