@@ -68,9 +68,14 @@ public:
     QString currentFollowersURL();
 
     void getUserProfile(QString userID);
+    void updateUserProfile(QString avatarURL, QString fullName,
+                           QString hometown, QString bio);
+
     void getAvatar(QString avatarURL);
     void getImage(QString imageURL);
+
     void getContactList(QString listType);
+    void getListsList();
 
     void getMainTimeline(int timelineOffset);
     void getDirectTimeline(int timelineOffset);
@@ -99,8 +104,11 @@ public:
         TokenRequest,
 
         UserProfileRequest,
+        UpdateProfileRequest,
+
         FollowingListRequest,
         FollowersListRequest,
+        ListsListRequest,
 
         MainTimelineRequest,
         DirectTimelineRequest,
@@ -135,8 +143,10 @@ public:
 signals:
     void authorizationStatusChanged(bool authorized);
 
-    void profileReceived(QString fullName, QString avatarURL);
+    void profileReceived(QString avatarURL, QString fullName,
+                         QString hometown, QString bio);
     void contactListReceived(QString listType, QVariantList contactList);
+    void listsListReceived(QVariantList listsList);
 
     void mainTimelineReceived(QVariantList postList, int postsPerPage,
                               QString previousLink, QString nextLink);
