@@ -38,8 +38,12 @@ TimeLine::TimeLine(int timelineType,
     demoPostData.insert("authorBio",      "I am not a real user");
     demoPostData.insert("authorHometown", "Demoville");
     demoPostData.insert("generator",      "Dianara");
+    demoPostData.insert("createdAt",      "2012-01-09T00:00:00Z");
 
 
+    QSettings settings; // FIXME: kinda tmp, until posts have "unread" status, etc.
+    settings.beginGroup("TimelineStates");
+
     // Demo post content depends on timeline type
     switch (this->timelineType)
     {
@@ -55,6 +59,7 @@ TimeLine::TimeLine(int timelineType,
 
                                       "<a href=\"http://jancoding.wordpress.com/dianara\">Dianara's blog</a><br>"
                                       "<br>");
+        this->previousNewestPostID = settings.value("previousNewestPostIDMain", "").toString();
         break;
 
 
@@ -64,6 +69,7 @@ TimeLine::TimeLine(int timelineType,
                                       "Here, you'll see posts specifically directed to you."
 
                                       "<br>");
+        this->previousNewestPostID = settings.value("previousNewestPostIDDirect", "").toString();
         break;
 
 
@@ -73,6 +79,7 @@ TimeLine::TimeLine(int timelineType,
                                       "You'll see your own posts here."
 
                                       "<br>");
+        this->previousNewestPostID = settings.value("previousNewestPostIDActivity", "").toString();
         break;
 
 
@@ -82,6 +89,7 @@ TimeLine::TimeLine(int timelineType,
                                       "Posts you've liked."
 
                                       "<br>");
+        this->previousNewestPostID = settings.value("previousNewestPostIDFavorites", "").toString();
         break;
 
 
@@ -90,8 +98,8 @@ TimeLine::TimeLine(int timelineType,
         demoPostData.insert("text", "<h2>Empty timeline</h2>");
 
     }
+    settings.endGroup();
 
-    demoPostData.insert("createdAt", "2012-01-09T00:00:00Z");
 
 
     splitter = new QSplitter(Qt::Vertical, this);
@@ -101,7 +109,7 @@ TimeLine::TimeLine(int timelineType,
 
     this->timelineOffset = 0;
 
-    firstPageButton = new QPushButton(QIcon::fromTheme("go-first"), tr("&First Page"));
+    firstPageButton = new QPushButton(QIcon::fromTheme("go-first"), tr("F&irst Page"));
     connect(firstPageButton, SIGNAL(clicked()),
             this, SLOT(goToFirstPage()));
 
@@ -137,10 +145,6 @@ TimeLine::TimeLine(int timelineType,
     this->setLayout(mainLayout);
 
 
-    // FIXME: take care of this for the different timelines
-    QSettings settings;
-    this->previousNewestPostID = settings.value("previousNewestPostID", "").toString();
-
     qDebug() << "TimeLine created";
 }
 
@@ -148,7 +152,28 @@ TimeLine::TimeLine(int timelineType,
 TimeLine::~TimeLine()
 {
     QSettings settings;
-    settings.setValue("previousNewestPostID", this->previousNewestPostID);
+    settings.beginGroup("TimelineStates");
+
+    switch (timelineType)
+    {
+    case TimelineTypeMain:
+        settings.setValue("previousNewestPostIDMain", this->previousNewestPostID);
+        break;
+
+    case TimelineTypeDirect:
+        settings.setValue("previousNewestPostIDDirect", this->previousNewestPostID);
+        break;
+
+    case TimelineTypeActivity:
+        settings.setValue("previousNewestPostIDActivity", this->previousNewestPostID);
+        break;
+
+    case TimelineTypeFavorites:
+        settings.setValue("previousNewestPostIDFavorites", this->previousNewestPostID);
+        break;
+    }
+    settings.endGroup();
+
 
     qDebug() << "TimeLine destroyed";
 }
@@ -531,27 +556,31 @@ void TimeLine::setTimeLineContents(QVariantList postList, int postsPerPage,
             }
 
 
-            /*
-            this->splitter->setStretchFactor(splitter->count()-1,
-                                             splitter->widget(splitter->count()-1)->height()/200);
-            */
+            // set stretch factor of 1 to each added post
+            this->splitter->setStretchFactor(splitter->count()-1,  1);
         }
         else  // singlePost.type() is not a QVariant::Map
         {
             qDebug() << "Expected a Map, got something else";
             qDebug() << postList;
         }
-    }
+    } // end foreach
+
+    // Add the "extra" empty widget
+    /*
+    this->splitter->addWidget(new QWidget());
+    this->splitter->setMinimumHeight(this->splitter->minimumHeight()
+                                     - splitter->widget(splitter->count()-1)->height());
+    */
 
     emit scrollToTop(); // ask mainWindow to scroll the QScrollArea containing the timeline to the top
 
     this->previousNewestPostID = newestPostID;
-
     qDebug() << "New posts:" << newPostCount << "; Newest post ID:" << previousNewestPostID;
 
     this->updateCurrentPageNumber();
 
-    emit timelineRendered(newPostCount);
+    emit timelineRendered(this->timelineType, newPostCount);
 
     qDebug() << "setTimeLineContents() /END";
 }
