@@ -54,9 +54,9 @@ public:
     enum TimelineTypes
     {
         TimelineTypeMain,
+        TimelineTypeDirect,
         TimelineTypeActivity,
-        TimelineTypeFavorites,
-        TimelineTypeDirect
+        TimelineTypeFavorites
     };
 
 
@@ -67,7 +67,7 @@ signals:
 
     void scrollToTop();
 
-    void timelineRendered(int newPostCount);
+    void timelineRendered(int timelineType, int newPostCount);
 
 public slots:
     void setTimeLineContents(QVariantList postList, int postsPerPage,
